# alacrity

Quickstart your Python project with a single handy command.

`pip install alacrity`

Call the module, answer some questions interactively, and poof, your package structure is ready.

Based on the [sample Python package](https://github.com/kennethreitz/samplemod) structure by Kenneth Reitz.

